@@ -17,7 +17,7 @@ series_search <- function(cik = NULL,
   if (res$status != "200") {
     stop("Unable to reach the SEC series search endpoint (https://www.sec.gov/cgi-bin/series)")
   }
-  doc <- xml2::read_html(res, base_url = href)
+  doc <- xml2::read_html(res, base_url = href, options = "HUGE")
 
   entries_xpath <- "//a[starts-with(.,'C')]"
 
